@@ -8,9 +8,10 @@ import requests
 
 from localtileserver.configure import get_default_client_params
 from localtileserver.server import ServerManager, launch_server
-from localtileserver.tileserver import get_clean_filename, palette_valid_or_raise
+from localtileserver.tileserver import get_building_docs, get_clean_filename, palette_valid_or_raise
 from localtileserver.utilities import add_query_parameters, save_file_from_request
 
+BUILDING_DOCS = get_building_docs()
 DEMO_REMOTE_TILE_SERVER = "https://tileserver.banesullivan.com/"
 logger = logging.getLogger(__name__)
 
@@ -324,12 +325,13 @@ class TileClient(BaseTileClient):
         debug: bool = False,
         threaded: bool = True,
         processes: int = 1,
+        host: str = "127.0.0.1",
         client_port: int = None,
         client_host: str = None,
         client_prefix: str = None,
     ):
         super().__init__(filename)
-        self._key = launch_server(port, debug, threaded=threaded, processes=processes)
+        self._key = launch_server(port, debug, threaded=threaded, processes=processes, host=host)
         # Store actual port just in case
         self._port = ServerManager.get_server(self._key).srv.port
         client_host, client_port, client_prefix = get_default_client_params(
@@ -338,6 +340,8 @@ class TileClient(BaseTileClient):
         self._client_host = client_host
         self._client_port = client_port
         self._client_prefix = client_prefix
+        if BUILDING_DOCS and not client_host:
+            self._client_host = DEMO_REMOTE_TILE_SERVER
 
     def shutdown(self, force: bool = False):
         if hasattr(self, "_key"):
@@ -389,12 +393,17 @@ class TileClient(BaseTileClient):
 
     @property
     def client_base_url(self):
+        scheme = (
+            "http://"
+            if self.client_host is not None and not self.client_host.startswith("http")
+            else ""
+        )
         if self.client_port is not None and self.client_host is not None:
-            base = f"http://{self.client_host}:{self.client_port}"
+            base = f"{scheme}{self.client_host}:{self.client_port}"
+        elif self.client_port is None and self.client_host is not None:
+            base = f"{scheme}{self.client_host}"
         elif self.client_port is not None and self.client_host is None:
             base = f"http://{self.server_host}:{self.client_port}"
-        elif self.client_port is None and self.client_host is not None:
-            base = f"http://{self.client_host}"
         else:
             base = "/"  # Use relative path
         if self.client_prefix is not None:
@@ -429,9 +438,9 @@ def get_or_create_tile_client(
 ):
     """A helper to safely get a TileClient from a path on disk.
 
-    To Do
-    -----
-    There should eventually be a check to see if a TileClient instance exists
+    Note
+    ----
+    TODO: There should eventually be a check to see if a TileClient instance exists
     for the given filename. For now, it is not really a big deal because the
     default is for all TileClient's to share a single server.
 
